@@ -86,16 +86,13 @@
 ;;;  50000108: 000000000000012D = package-id #x0001 | symbol-widetag
 ;;;  50000110: 0000000050000117 = NIL-VALUE
 ;;;  50000118: 0000000050000117
-      (inst cmp  object nil-value)
+      (inst cmp  object null-tn)
       (inst mov :byte rax sb-kernel::index-of-layout-for-NULL)
       (inst cmov :dword :ne rax object)
       (inst movzx '(:byte :dword) rax rax) ; same as "AND EAX,255" but shorter encoding
       LOAD-FROM-VECTOR
-      (inst mov :dword result
-            (ea (make-fixup '**primitive-object-layouts** :symbol-value
-                           (- (ash vector-data-offset word-shift)
-                              other-pointer-lowtag))
-                nil rax 8)) ; no base register
+      (inst mov :dword result (ea (- (ash vector-data-offset word-shift) nil-value-offset)
+                                  null-tn rax 8))
       DONE))
 (define-vop ()
     (:policy :fast-safe)
@@ -215,15 +212,6 @@
     (multiple-value-bind (imm8 shift) (header-byte-imm8 mask)
       (inst test :byte (ea (- (1+ shift) other-pointer-lowtag) array) imm8)))))
 
-(define-vop (pointer-hash)
-  (:translate pointer-hash)
-  (:args (ptr :scs (any-reg descriptor-reg) :target res))
-  (:results (res :scs (any-reg descriptor-reg)))
-  (:policy :fast-safe)
-  (:generator 1
-    (move res ptr)
-    (inst and res (lognot fixnum-tag-mask))))
-
 ;;;; allocation
 
 (define-vop (binding-stack-pointer-sap)
